// eslint-disable-next-line
import {
  UserLayout,
  BasicLayout,
  RouteView,
  PageView
} from '@/layouts'

export const asyncRouterMap = [{
  path: '/',
  name: 'index',
  component: BasicLayout,
  meta: {
    title: 'IT后台'
  },
  redirect: '/home',
  children: [{
    path: '/home',
    name: 'home',
    redirect: '/home',
    component: PageView,
    meta: {
      title: '首页',
      icon: 'home'
    },
    hideChildrenInMenu: true,
    children: [{
      path: '/home',
      name: 'home',
      component: () => import(/* webpackChunkName: "home" */ '@/views/Home'),
      meta: {
        title: '首页',
        icon: 'home',
        hiddenHeaderContent: true
      }
    }
    ]
  },
  {
    path: '/changePwd',
    name: 'changePwd',
    hidden: true,
    component: () => import(/* webpackChunkName: "changePwd" */ '@/views/user/ChangePwd'),
    meta: {
      title: '修改密码',
      icon: 'home'
    }
  },
  {
    path: '/tenants',
    redirect: '/tenants/list',
    component: PageView,
    meta: {
      title: '租户管理',
      icon: 'team',
      permission: 'M_tenants_list'
    },
    children: [{
      path: '/tenants/list',
      name: 'tenantsList',
      component: () => import(/* webpackChunkName: "tenants" */ '@/views/tenants/tenantsList.vue'),
      meta: {
        title: '租户列表',
        icon: 'team',
        permission: 'M_tenants_list'
      }
    }]
  },
  // 考评管理
  {
    path: '/evaluation',
    redirect: '/evaluation/evaluationItem',
    component: PageView,
    meta: {
      title: '考评管理',
      icon: 'block',
      permission: 'M_evaluation_0'
    },
    children: [{
      path: '/evaluation/evaluationItem',
      name: 'EvaluationItem',
      component: () => import(/* webpackChunkName: "evaluation" */
        '@/views/evaluation/evaluationItem/EvaluationItem.vue'),
      meta: {
        title: '考评项目',
        icon: 'save',
        permission: 'M_evaluationItem_list'
      }
    }, {
      path: '/evaluation/evaluationPlan',
      name: 'EvaluationPlan',
      component: () => import(/* webpackChunkName: "evaluation" */
        '@/views/evaluation/evaluationPlan/EvaluationPlan.vue'),
      meta: {
        title: '考评方案',
        icon: 'switcher',
        permission: 'M_evaluationPlan_list'
      }
    }]
  },
  // 业务 设置setting
  {
    path: '/bnSetting',
    redirect: '/bnSetting/menusAuth',
    component: PageView,
    meta: {
      title: '平台设置',
      icon: 'security-scan',
      permission: 'M_bnSetting_0'
    },
    children: [{
      path: '/bnSetting/menusAuth',
      name: 'menusAuth',
      component: () => import(/* webpackChunkName: "bnSetting" */ '@/views/bnSetting/menusAuthTab.vue'),
      meta: {
        title: '菜单授权',
        icon: 'property-safety',
        permission: 'M_bnSetting_0'
      }
    }]
  },
  {
    path: '/appSetting',
    redirect: '/appSetting/bannerSetting',
    component: PageView,
    meta: {
      title: 'APP设置',
      icon: 'appstore',
      permission: 'M_appSetting'
    },
    children: [{
      path: '/appSetting/bannerSetting',
      name: 'bannerSetting',
      component: () => import(/* webpackChunkName: "appSetting" */ '@/views/appSetting/bannerSetting.vue'),
      meta: {
        title: '营销图设置',
        icon: 'file-image',
        permission: 'M_banner'
      }
    },
    {
      path: '/editionSetting',
      redirect: '/editionSetting/list',
      name: 'editionSetting',
      component: RouteView,
      meta: {
        title: '版本设置',
        icon: 'info-circle',
        permission: 'M_banben'
      },
      hideChildrenInMenu: true,
      children: [{
        path: '/editionSetting/list',
        name: 'editionSetting_list',
        component: () => import(/* webpackChunkName: "appSetting" */
          '@/views/appSetting/editionSetting.vue'),
        meta: {
          title: '列表',
          icon: 'interaction',
          permission: 'M_banben'
        }
      },
      {
        path: '/editionSetting/add',
        name: 'editionSetting_add',
        component: () => import(/* webpackChunkName: "appSetting" */
          '@/views/appSetting/addEditionSetting.vue'),
        meta: {
          title: '新增',
          icon: 'crown',
          hidden: true
        }
      },
      {
        path: '/editionSetting/add',
        name: 'editionSetting_edit',
        component: () => import(/* webpackChunkName: "appSetting" */
          '@/views/appSetting/addEditionSetting.vue'),
        meta: {
          title: '编辑',
          icon: 'crown',
          hidden: true
        }
      }
      ]
    }
    ]

  },
  {
    path: '/menusAuth',
    redirect: '/bnSetting/menusAuth',
    component: PageView,
    meta: {
      title: '菜单管理',
      icon: 'bars',
      permission: 'M_menusAuth_0'
    },
    children: [{
      path: '/menusAuth/storeMenus',
      name: 'storeMenus',
      component: () => import(/* webpackChunkName: "bnSetting" */ '@/views/bnSetting/menu/storeMenus.vue'),
      meta: {
        title: '巡店菜单管理',
        icon: 'shop',
        permission: 'M_menusAuth_storeMenus'
      }
    },
    {
      path: '/menusAuth/adminMenus',
      name: 'adminMenus',
      component: () => import(/* webpackChunkName: "bnSetting" */ '@/views/bnSetting/menu/adminMenus.vue'),
      meta: {
        title: '运营菜单管理',
        icon: 'appstore',
        permission: 'M_menusAuth_adminMenus'
      }
    },
    {
      path: '/menusAuth/menu',
      name: 'powerMenu',
      component: () => import(/* webpackChunkName: "auth" */ '@/views/power/menu/menu.vue'),
      meta: {
        title: 'IT菜单管理',
        icon: 'profile',
        permission: 'M_menusAuth_menu'
      }
    }
    ]
  },
  // auth
  {
    path: '/auth',
    redirect: '/auth/userList',
    component: PageView,
    meta: {
      title: 'IT权限管理',
      icon: 'lock',
      permission: 'M_auth_0'
    },
    children: [{
      path: '/auth/userList',
      name: 'powerUserList',
      component: () => import(/* webpackChunkName: "auth" */ '@/views/power/user/userList.vue'),
      meta: {
        title: '用户管理',
        icon: 'user',
        permission: 'M_auth_userList'
      }
    },
    {
      path: '/auth/roleList',
      name: 'powerRoleList',
      component: () => import(/* webpackChunkName: "auth" */ '@/views/power/role/roleList.vue'),
      meta: {
        title: '角色管理',
        icon: 'solution',
        permission: 'M_auth_roleList'
      }
    }
    ]
  },
  {
    path: '/setting',
    redirect: '/setting/userList',
    component: PageView,
    meta: {
      title: '系统设置',
      icon: 'setting',
      permission: 'M_setting_0'
    },
    children: [{
      path: '/setting/dataDictionary',
      name: 'powerDD',
      component: () => import(/* webpackChunkName: "setting" */
        '@/views/power/dataDictionary/dataDictionary.vue'),
      meta: {
        title: '数据字典管理',
        icon: 'database',
        permission: 'M_sys_dataDictionary'
      }
    },
    // {
    //   path: '/setting/register',
    //   name: 'powerRegister',
    //   component: () => import(/* webpackChunkName: "setting" */ '@/views/power/register/register.vue'),
    //   meta: {
    //     title: '参数管理',
    //     icon: 'key'
    //     // permission: 'M_sys_register'
    //   }
    // },
    // {
    //   path: '/setting/jobs',
    //   name: 'powerJobs',
    //   component: () => import(/* webpackChunkName: "setting" */ '@/views/power/job/jobs.vue'),
    //   meta: {
    //     title: '定时器',
    //     icon: 'alert',
    //     permission: 'M_sys_job'
    //   }
    // },
    {
      path: '/setting/OperateJournal',
      name: 'powerOperateJournal',
      component: () => import(/* webpackChunkName: "setting" */
        '@/views/power/OperateJournal/OperateJournal.vue'),
      meta: {
        title: '操作日志',
        icon: 'read',
        permission: 'M_operateJournal'
      }
    }
    ]
  }
  ]
},
{
  path: '*',
  redirect: '/404',
  hidden: true
}
]

/**
 * 基础路由
 * @type { *[] }
 */
export const constantRouterMap = [{
  path: '/user',
  component: UserLayout,
  redirect: '/user/login',
  hidden: true,
  children: [{
    path: 'login',
    name: 'login',
    component: () => import(/* webpackChunkName: "user" */ '@/views/user/Login')
  },
  {
    path: 'register',
    name: 'register',
    component: () => import(/* webpackChunkName: "user" */ '@/views/user/Register')
  },
  {
    path: 'register-result',
    name: 'registerResult',
    component: () => import(/* webpackChunkName: "user" */ '@/views/user/RegisterResult')
  },
  {
    path: 'recover',
    name: 'recover',
    component: undefined
  }
  ]
},
{
  path: '/404',
  component: () => import(/* webpackChunkName: "fail" */ '@/views/exception/404')
}

]
